@@ -254,7 +254,8 @@ class ContentSequence(DataElementSequence):
         items: Optional[
             Union[Sequence[ContentItem], 'ContentSequence']
         ] = None,
-        is_root: bool = False
+        is_root: bool = False,
+        is_sr: bool = True
     ) -> None:
         """
 
@@ -266,34 +267,23 @@ class ContentSequence(DataElementSequence):
             Whether the sequence is used to contain SR Content Items that are
             intended to be added to an SR document at the root of the document
             content tree
+        is_sr: bool, optional
+            Whether the sequence is use to contain SR Content Items that are
+            intended to be added to an SR document as opposed to other types
+            of IODs based on an acquisition, protocol or workflow context
+            template
 
         """  # noqa: E501
         self._is_root = is_root
-        if items is not None:
-            for i in items:
-                if not isinstance(i, ContentItem):
-                    raise TypeError(
-                        f'Items of "{self.__class__.__name__}" must have '
-                        'type ContentItem.'
-                    )
-                if is_root:
-                    if i.relationship_type is not None:
-                        raise AttributeError(
-                            'Item at the root of the content tree must '
-                            f'have no Relationship Type:\n{i.name}.'
-                        )
-                    if not isinstance(i, ContainerContentItem):
-                        raise TypeError(
-                            'Item at the root of a SR content tree must '
-                            f'have type ContainerContentItem:\n{i.name}'
-                        )
-                else:
-                    if i.relationship_type is None:
-                        raise AttributeError(
-                            'Item to be included in a '
-                            f'{self.__class__.__name__} must have an '
-                            f'established relationship type:\n{i.name}'
-                        )
+        self._is_sr = is_sr
+
+        if is_root and not is_sr:
+            raise ValueError(
+                'Argument "is_root" is True but "is_sr" is False. '
+                'SR content items that are intended to be included at the '
+                'root of a document content tree must also be intended to be '
+                'added to a SR document.'
+            )
 
         # The implementation of this class is quite a hack. It is derived from
         # "pydicom.sequence.Sequence", because this is the only type that is
@@ -321,6 +311,39 @@ class ContentSequence(DataElementSequence):
         else:
             super().__init__()
 
+        if items is not None:
+            for i in items:
+                if not isinstance(i, ContentItem):
+                    raise TypeError(
+                        f'Items of "{self.__class__.__name__}" must have '
+                        'type ContentItem.'
+                    )
+                if is_root:
+                    if i.relationship_type is not None:
+                        raise AttributeError(
+                            'Item at the root of the content tree must '
+                            f'have no Relationship Type:\n{i.name}.'
+                        )
+                    if not isinstance(i, ContainerContentItem):
+                        raise TypeError(
+                            'Item at the root of a SR content tree must '
+                            f'have type ContainerContentItem:\n{i.name}'
+                        )
+                elif is_sr:
+                    if i.relationship_type is None:
+                        raise AttributeError(
+                            'Item to be included in a '
+                            f'{self.__class__.__name__} must have an '
+                            f'established relationship type:\n{i.name}'
+                        )
+                else:
+                    if i.relationship_type is not None:
+                        raise AttributeError(
+                            'Item of content of acquisition, protocol, or '
+                            'workflow context must have no Relationship Type: '
+                            f'\n{i.name}.'
+                        )
+
     @overload
     def __setitem__(self, idx: int, val: ContentItem) -> None:
         pass
@@ -415,7 +438,11 @@ class ContentSequence(DataElementSequence):
             Matched content items
 
         """
-        return ContentSequence(self._lut[name])
+        return ContentSequence(
+            self._lut[name],
+            is_root=False,
+            is_sr=self._is_sr
+        )
 
     def get_nodes(self) -> 'ContentSequence':
         """Get content items that represent nodes in the content tree.
@@ -450,14 +477,14 @@ class ContentSequence(DataElementSequence):
                 )
             )
         if self._is_root:
-            if val.relationship_type is not None:
+            if self._is_sr and val.relationship_type is not None:
                 raise AttributeError(
                     f'Items to be appended to a {self.__class__.__name__} '
                     'that is the root of the SR content tree must not have '
                     'relationship type.'
                 )
         else:
-            if val.relationship_type is None:
+            if self._is_sr and val.relationship_type is None:
                 raise AttributeError(
                     f'Items to be appended to a {self.__class__.__name__} must '
                     'have an established relationship type.'
@@ -522,7 +549,8 @@ class ContentSequence(DataElementSequence):
     def from_sequence(
         cls,
         sequence: Sequence[Dataset],
-        is_root: bool = False
+        is_root: bool = False,
+        is_sr: bool = True
     ) -> 'ContentSequence':
         """Construct object from a sequence of datasets.
 
@@ -534,6 +562,11 @@ class ContentSequence(DataElementSequence):
             Whether the sequence is used to contain SR Content Items that are
             intended to be added to an SR document at the root of the document
             content tree
+        is_sr: bool, optional
+            Whether the sequence is use to contain SR Content Items that are
+            intended to be added to an SR document as opposed to other types
+            of IODs based on an acquisition, protocol or workflow context
+            template
 
         Returns
         -------
@@ -546,18 +579,20 @@ class ContentSequence(DataElementSequence):
             cls._check_dataset(
                 dataset,
                 is_root=is_root,
+                is_sr=is_sr,
                 index=i
             )
             dataset_copy = deepcopy(dataset)
             item = ContentItem._from_dataset_derived(dataset_copy)
             content_items.append(item)
-        return ContentSequence(content_items, is_root=is_root)
+        return ContentSequence(content_items, is_root=is_root, is_sr=is_sr)
 
     @classmethod
     def _from_sequence(
         cls,
         sequence: Sequence[Dataset],
-        is_root: bool = False
+        is_root: bool = False,
+        is_sr: bool = True
     ) -> 'ContentSequence':
         """Construct object from a sequence of datasets.
 
@@ -569,6 +604,11 @@ class ContentSequence(DataElementSequence):
             Whether the sequence is used to contain SR Content Items that are
             intended to be added to an SR document at the root of the document
             content tree
+        is_sr: bool, optional
+            Whether the sequence is use to contain SR Content Items that are
+            intended to be added to an SR document as opposed to other types
+            of IODs based on an acquisition, protocol or workflow context
+            template
 
         Returns
         -------
@@ -581,17 +621,19 @@ class ContentSequence(DataElementSequence):
             cls._check_dataset(
                 dataset,
                 is_root=is_root,
+                is_sr=is_sr,
                 index=i
             )
             item = ContentItem._from_dataset_derived(dataset)
             content_items.append(item)
-        return ContentSequence(content_items, is_root=is_root)
+        return ContentSequence(content_items, is_root=is_root, is_sr=is_sr)
 
     @classmethod
     def _check_dataset(
         cls,
         dataset: Dataset,
         is_root: bool,
+        is_sr: bool,
         index: int
     ) -> None:
         if not isinstance(dataset, Dataset):
@@ -612,9 +654,9 @@ class ContentSequence(DataElementSequence):
                 f'Item #{index} of sequence is not an SR Content Item:\n'
                 f'{dataset}'
             )
-        if not hasattr(dataset, 'RelationshipType') and not is_root:
+        if not hasattr(dataset, 'RelationshipType') and not is_root and is_sr:
             raise AttributeError(
-                'Item #{index} of sequence is not a value SR Content Item '
+                f'Item #{index} of sequence is not a value SR Content Item '
                 'because it is not a root item and lacks the otherwise '
                 f'required attribute "RelationshipType":\n{dataset}'
             )
@@ -627,6 +669,11 @@ class ContentSequence(DataElementSequence):
         """
         return self._is_root
 
+    @property
+    def is_sr(self) -> bool:
+        """bool: whether the sequence is intended for use in an SR document"""
+        return self._is_sr
+
 
 class CodeContentItem(ContentItem):
 
