@@ -97,8 +97,8 @@ def compute_plane_position_tiled_full(
     spacing_between_slices: Union[float, None], optional
         Distance between neighboring focal planes in micrometers
     slice_index: Union[int, None], optional
-        Relative one-based index of the slice in the array of slices
-        within the volume
+        Relative one-based index of the focal plane in the array of focal
+        planes within the imaged volume from the slide to the coverslip
 
     Returns
     -------
@@ -188,9 +188,14 @@ def compute_plane_position_slide_per_frame(
     )
     num_focal_planes = getattr(
         dataset,
-        'NumberOfFocalPlanes',
+        'TotalPixelMatrixFocalPlanes',
         1
     )
+    num_optical_paths = getattr(
+        dataset,
+        'NumberOfOpticalPaths',
+        len(dataset.OpticalPathSequence)
+    )
 
     shared_fg = dataset.SharedFunctionalGroupsSequence[0]
     pixel_measures = shared_fg.PixelMeasuresSequence[0]
@@ -223,7 +228,8 @@ def compute_plane_position_slide_per_frame(
             spacing_between_slices=spacing_between_slices,
             slice_index=s,
         )
-        for s, r, c in itertools.product(
+        for _, s, r, c in itertools.product(
+            range(num_optical_paths),
             range(1, num_focal_planes + 1),
             range(1, tiles_per_column + 1),  # column direction, top to bottom
             range(1, tiles_per_row + 1),  # row direction, left to right
